isAttached property
bool
get
isAttached
Whether this controller is attached to a mounted form.
Implementation
bool get isAttached => _delegate != null;
Whether this controller is attached to a mounted form.
bool get isAttached => _delegate != null;